@@ -1,5 +1,8 @@
 package Log::Any::App;
 
+our $DATE = '2014-12-05'; # DATE
+our $VERSION = '0.47'; # VERSION
+
 # i need this to run on centos 5.x. otherwise all my other servers are debian
 # 5.x and 6.x+ (perl 5.010).
 use 5.008000;
@@ -11,7 +14,6 @@ use File::Spec;
 use Log::Any 0.14;
 use Log::Any::Adapter;
 
-our $VERSION = '0.46'; # VERSION
 
 use vars qw($dbg_ctx);
 
@@ -845,8 +847,8 @@ sub _parse_opt_unixsock {
             #
             #if ($ospec->{create} && !(-e $ospec->{path})) {
             #    _debug("Creating Unix socket $ospec->{path} ...");
-            #    require SHARYANTO::IO::Socket::UNIX::Util;
-            #    SHARYANTO::IO::Socket::UNIX::Util::create_unix_socket(
+            #    require IO::Socket::UNIX::Util;
+            #    IO::Socket::UNIX::Util::create_unix_socket(
             #        $ospec->{path});
             #}
         },
@@ -1139,7 +1141,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-This document describes version 0.46 of Log::Any::App (from Perl distribution Log-Any-App), released on 2014-07-06.
+This document describes version 0.47 of Log::Any::App (from Perl distribution Log-Any-App), released on 2014-12-05.
 
 =head1 SYNOPSIS
 
@@ -1876,13 +1878,13 @@ because that will be interpreted as multiple array outputs:
 
  -array => [{output1}, ...]
 
-If the argument is a false boolean value, Unix domain socket logging will be
-turned off. Otherwise argument must be a hashref or an arrayref (to specify
-multiple outputs). If the argument is a hashref, then the keys of the hashref
-must be one of: C<level>, C<array> (defaults to new anonymous array []),
-C<filter_text>, C<filter_no_text>, C<filter_citext>, C<filter_no_citext>,
-C<filter_re>, C<filter_no_re>. If the argument is an arrayref, it is assumed to
-be specifying multiple sockets, with each element of the array as a hashref.
+If the argument is a false boolean value, array logging will be turned off.
+Otherwise argument must be a hashref or an arrayref (to specify multiple
+outputs). If the argument is a hashref, then the keys of the hashref must be one
+of: C<level>, C<array> (defaults to new anonymous array []), C<filter_text>,
+C<filter_no_text>, C<filter_citext>, C<filter_no_citext>, C<filter_re>,
+C<filter_no_re>. If the argument is an arrayref, it is assumed to be specifying
+multiple sockets, with each element of the array as a hashref.
 
 How Log::Any::App determines defaults for array logging:
 
@@ -2119,15 +2121,16 @@ are reasonably simple and should be supported by Log::Any::App).
 =head2 What is array output for?
 
 Logging to a Perl array might be useful for testing/debugging, or (one use-case
-I can think of) for letting users of your program connect/request your program
-to view the logs being produced. For example, here is a program that uses a
-separate thread to listen to Unix socket. Requires perl built with threads
-enabled.
+I can think of) for letting users of your program connect to your program
+directly to request viewing the logs being produced (although logging to other
+outputs doesn't preclude this ability). For example, here is a program that uses
+a separate thread to listen to Unix socket for requests to view the (last 100)
+logs. Requires perl built with threads enabled.
 
  use threads;
  use threads::shared;
  BEGIN { our @buf :shared }
- use SHARYANTO::IO::Socket::UNIX::Util qw(create_unix_stream_socket);
+ use IO::Socket::UNIX::Util qw(create_unix_stream_socket);
  use Log::Any::App '$log', -array => [{array => 'main::buf', max_elems=>100}];
 
  my $sock = create_unix_stream_socket('/tmp/app-logview.sock');
@@ -2245,7 +2248,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Ap
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Log-Any-App>.
+Source repository is at L<https://github.com/perlancar/perl-Log-Any-App>.
 
 =head1 BUGS
 
@@ -2257,11 +2260,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
